@@ -6,7 +6,7 @@
 ##############################################################################
 
 __doc__     = """ ActiveDirectoryUserFolder shim module """
-__version__ = '$Revision: 1372 $'[11:-2]
+__version__ = '$Revision: 1481 $'[11:-2]
 
 # General Python imports
 import logging
@@ -21,12 +21,14 @@ from Globals import package_home
 from AccessControl import ClassSecurityInfo
 from Products.LDAPUserFolder import manage_addLDAPUserFolder
 from Products.LDAPUserFolder.LDAPDelegate import filter_format
+from Products.LDAPUserFolder.utils import BINARY_ATTRIBUTES
+
+from zope.interface import implementedBy
 
 from Products.PluggableAuthService.interfaces.plugins import \
      IUserEnumerationPlugin, IGroupsPlugin, IGroupEnumerationPlugin, \
      IRoleEnumerationPlugin
 from Products.PluggableAuthService.utils import classImplements
-from Products.PluggableAuthService.utils import implementedBy
 
 from LDAPPluginBase import LDAPPluginBase
 
@@ -202,7 +204,11 @@ class ActiveDirectoryMultiPlugin(LDAPPluginBase):
         R = delegate.search(acl.groups_base, acl.groups_scope, filter=filt)
 
         if R['exception']:
-            raise RuntimeError, R['exception']
+            logger.error("Failed to locate groups for principal in %s "
+                         "(scope=%s, filter=%s): %s",
+                         acl.groups_base, acl.groups_scope, filt,
+                         R['exception'])
+            return ()
         if self.group_recurse:
             groups = self._recurseGroups(R['results'])
         else:
@@ -246,11 +252,14 @@ class ActiveDirectoryMultiPlugin(LDAPPluginBase):
             acl = self.acl_users
             delegate = acl._delegate
             R = delegate.search(acl.groups_base, acl.groups_scope, filter=filt)
-            
             if R['exception']:
-                raise RuntimeError, R['exception']
-            if depth < self.group_recurse_depth:    
-                self._recurseGroups(R['results'], temp, seen, depth + 1)
+                logger.error("Failed to recursively search for group in %s "
+                             "(scope=%s, filter=%s): %s",
+                             acl.groups_base, acl.groups_scope, filt,
+                             R['exception'])
+            else:
+                if depth < self.group_recurse_depth:    
+                    self._recurseGroups(R['results'], temp, seen, depth + 1)
 
         return temp
 
@@ -400,23 +409,35 @@ class ActiveDirectoryMultiPlugin(LDAPPluginBase):
         elif id is None:
             id = ''
             
-        test_id = id.lower()
         plugin_id = self.getId()
 
         filt = ['(objectClass=%s)' % self.group_class]
-        if not test_id:
+        if not id:
             filt.append('(%s=*)' % self.groupid_attr)
         elif exact_match:
-            filt.append(filter_format('(%s=%s)',(self.groupid_attr, test_id)))
-        elif test_id:
-            filt.append(filter_format('(%s=*%s*)',(self.groupid_attr, test_id)))
+            filt.append(filter_format('(%s=%s)',(self.groupid_attr, id)))
+        elif id:
+            filt.append(filter_format('(%s=*%s*)',(self.groupid_attr, id)))
         filt = '(&%s)' % ''.join(filt)
 
+        if self.groupid_attr.lower() in BINARY_ATTRIBUTES:
+            convert_filter = False
+        else:
+            convert_filter = True
+
         delegate = acl._delegate
-        R = delegate.search(acl.groups_base, acl.groups_scope, filter=filt)
+        R = delegate.search( acl.groups_base
+                           , acl.groups_scope
+                           , filter=filt
+                           , convert_filter=convert_filter
+                           )
 
         if R['exception']:
-            raise RuntimeError, R['exception']
+            logger.error("Failed to enumerate groups in %s "
+                         "(scope=%s, filter=%s): %s",
+                         acl.groups_base, acl.groups_scope, filt,
+                         R['exception'])
+            return ()
 
         groups = R['results']
 
