@@ -9,13 +9,11 @@
 ##############################################################################
 
 __doc__     = """ LDAPUserFolder shim module """
-__version__ = '$Revision: 1389 $'[11:-2]
+__version__ = '$Revision: 1428 $'[11:-2]
 
 # General Python imports
-import copy
 import logging
 import os
-import operator
 from urllib import quote_plus
 
 # Zope imports
@@ -116,6 +114,17 @@ class LDAPMultiPlugin(LDAPPluginBase):
     security.declarePrivate('getGroupsForPrincipal')
     def getGroupsForPrincipal(self, user, request=None, attr=None):
         """ Fulfill GroupsPlugin requirements """
+        view_name = self.getId() + '_getGroupsForPrincipal'
+        criteria = {'id':user.getId(), 'attr':attr}
+
+        cached_info = self.ZCacheable_get(view_name = view_name,
+                                          keywords = criteria,
+                                          default = None)
+
+        if cached_info is not None:
+            logger.debug('returning cached results from enumerateUsers')
+            return cached_info
+
         acl = self._getLDAPUserFolder()
 
         if acl is None:
@@ -132,7 +141,10 @@ class LDAPMultiPlugin(LDAPPluginBase):
 
         groups = acl.getGroups(ldap_user.getUserDN(), attr=attr)
 
-        return tuple([x[0] for x in groups])
+        result = tuple([x[0] for x in groups])
+        self.ZCacheable_set(result, view_name=view_name, keywords=criteria)
+
+        return result
 
 
     security.declarePrivate('enumerateUsers')
